@@ -1,15 +1,11 @@
 package XML::XSS;
-BEGIN {
-  $XML::XSS::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $XML::XSS::VERSION = '0.3.4';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: XML stylesheet system
-
+$XML::XSS::VERSION = '0.3.5';
 
 use 5.10.0;
 
+
 use MooseX::SemiAffordanceAccessor;
 use Moose;
 use MooseX::ClassAttribute;
@@ -27,6 +23,8 @@ use XML::XSS::Template;
 
 use MooseX::Clone;
 
+use experimental 'smartmatch';
+
 with 'MooseX::Clone';
 
 no warnings qw/ uninitialized /;
@@ -352,13 +350,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 XML::XSS - XML stylesheet system
 
 =head1 VERSION
 
-version 0.3.4
+version 0.3.5
 
 =head1 SYNOPSIS
 
@@ -682,7 +682,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yanick Champoux.
+This software is copyright (c) 2017, 2013, 2011, 2010 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
