@@ -1,12 +1,7 @@
 package XML::XSS::Comment;
-BEGIN {
-  $XML::XSS::Comment::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $XML::XSS::Comment::VERSION = '0.3.4';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: XML::XSS comment stylesheet rule
-
+$XML::XSS::Comment::VERSION = '0.3.5';
 
 use 5.10.0;
 
@@ -69,13 +64,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 XML::XSS::Comment - XML::XSS comment stylesheet rule
 
 =head1 VERSION
 
-version 0.3.4
+version 0.3.5
 
 =head1 SYNOPSIS
 
@@ -116,7 +113,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yanick Champoux.
+This software is copyright (c) 2017, 2013, 2011, 2010 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
