@@ -1,12 +1,7 @@
 package XML::XSS::ProcessingInstruction;
-BEGIN {
-  $XML::XSS::ProcessingInstruction::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $XML::XSS::ProcessingInstruction::VERSION = '0.3.4';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: XML::XSS processing instruction stylesheet rule
-
+$XML::XSS::ProcessingInstruction::VERSION = '0.3.5';
 use 5.10.0;
 
 use Moose;
@@ -42,13 +37,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 XML::XSS::ProcessingInstruction - XML::XSS processing instruction stylesheet rule
 
 =head1 VERSION
 
-version 0.3.4
+version 0.3.5
 
 =head1 AUTHOR
 
@@ -56,7 +53,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yanick Champoux.
+This software is copyright (c) 2017, 2013, 2011, 2010 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
