@@ -1,15 +1,12 @@
 package XML::XSS::Role::Renderer;
-BEGIN {
-  $XML::XSS::Role::Renderer::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $XML::XSS::Role::Renderer::VERSION = '0.3.4';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: XML::XSS role for rendering rule
-
+$XML::XSS::Role::Renderer::VERSION = '0.3.5';
 use Moose::Role;
 use MooseX::SemiAffordanceAccessor;
 
+use experimental 'smartmatch';
+
 use Scalar::Util qw/ refaddr /;
 
 has stylesheet => (
@@ -144,13 +141,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 XML::XSS::Role::Renderer - XML::XSS role for rendering rule
 
 =head1 VERSION
 
-version 0.3.4
+version 0.3.5
 
 =head1 OVERLOADING
 
@@ -209,7 +208,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yanick Champoux.
+This software is copyright (c) 2017, 2013, 2011, 2010 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
