@@ -1,12 +1,7 @@
 package XML::XSS::Role::StyleAttribute;
-BEGIN {
-  $XML::XSS::Role::StyleAttribute::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $XML::XSS::Role::StyleAttribute::VERSION = '0.3.4';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Trait of style attributes
-
+$XML::XSS::Role::StyleAttribute::VERSION = '0.3.5';
 use Moose::Role;
 use XML::XSS::StyleAttribute;
 
@@ -32,13 +27,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 XML::XSS::Role::StyleAttribute - Trait of style attributes
 
 =head1 VERSION
 
-version 0.3.4
+version 0.3.5
 
 =head1 AUTHOR
 
@@ -46,7 +43,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yanick Champoux.
+This software is copyright (c) 2017, 2013, 2011, 2010 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
