@@ -1,11 +1,6 @@
 package XML::XSS::Stylesheet::HTML2TD;
-BEGIN {
-  $XML::XSS::Stylesheet::HTML2TD::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $XML::XSS::Stylesheet::HTML2TD::VERSION = '0.3.4';
-}
-
+our $AUTHORITY = 'cpan:YANICK';
+$XML::XSS::Stylesheet::HTML2TD::VERSION = '0.3.5';
 use Moose;
 use XML::XSS;
 use Perl::Tidy;
@@ -76,13 +71,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 XML::XSS::Stylesheet::HTML2TD
 
 =head1 VERSION
 
-version 0.3.4
+version 0.3.5
 
 =head1 AUTHOR
 
@@ -90,7 +87,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yanick Champoux.
+This software is copyright (c) 2017, 2013, 2011, 2010 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
