@@ -1,12 +1,7 @@
 package XML::XSS::Text;
-BEGIN {
-  $XML::XSS::Text::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $XML::XSS::Text::VERSION = '0.3.4';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: XML::XSS text stylesheet rule
-
+$XML::XSS::Text::VERSION = '0.3.5';
 
 
 use Moose;
@@ -81,13 +76,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 XML::XSS::Text - XML::XSS text stylesheet rule
 
 =head1 VERSION
 
-version 0.3.4
+version 0.3.5
 
 =head1 SYNOPSIS
 
@@ -163,7 +160,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yanick Champoux.
+This software is copyright (c) 2017, 2013, 2011, 2010 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
